searchData={"items":[{"type":"module","title":"MutableMap","doc":"# MutableMap\n\nLarge, no worries mutable maps for Elixir. These `MutableMap`s can be used as drop-in replacements for `Map`s, but can also be used as a shared, mutable, concurrent data store.\n\nMultiple processes can safely read and write to the same `MutableMap` without the need for locking or other synchronization mechanisms. When no process is using the `MutableMap` anymore, it is automatically garbage collected like normal Elixir Maps.","ref":"MutableMap.html"},{"type":"module","title":"Motivation - MutableMap","doc":"When working with large data sets, Elixir's `Map`s and `Keyword`s can become unwieldy. E.g. when using large maps (200mb+) then sending them between processes becomes really slow (Easily 50ms and more for one `send(pid, large_map)`). On the other hand Erlang `:ets` tables can solve this problem, but their API is unwieldy and they require explicit creation and cleaning up.\n\nInstead `MutableMap`s offer an easy to use, performant and most importantly lazy garbage collected data storage solution.","ref":"MutableMap.html#module-motivation"},{"type":"module","title":"Usage - MutableMap","doc":"```elixir\n# Create a new MutableMap\nMutableMap.new()\n\n# Create a new MutableMap from a list\nMutableMap.new([{1, 2}, {3, 4}])\n\n# Set and get values\nMutableMap.put(map, 1, 2)\nMutableMap.get(map, 1)\n\n# Delete values\nMutableMap.delete(map, 1)\n\n# Since MutableMaps are mutable they can be explicitly copied to create different instances\n\nmap1 = MutableMap.new()\nmap2 = map1\nMutableMap.put(map1, :a, 1)\nMutableMap.to_list(map1)\n# => [:a, 1]\nMutableMap.to_list(map2)\n# => [:a, 1]\nmap3 = MutableMap.new(map1)\nMutableMap.put(map3, :b, 2)\nMutableMap.to_list(map1)\n# => [:a, 1]\nMutableMap.to_list(map3) |> Enum.sort()\n# => [:a, 1, :b, 2]\n```","ref":"MutableMap.html#module-usage"},{"type":"function","title":"MutableMap.delete/2","doc":"","ref":"MutableMap.html#delete/2"},{"type":"function","title":"MutableMap.empty?/1","doc":"","ref":"MutableMap.html#empty?/1"},{"type":"function","title":"MutableMap.get/3","doc":"","ref":"MutableMap.html#get/3"},{"type":"function","title":"MutableMap.has_key?/2","doc":"","ref":"MutableMap.html#has_key?/2"},{"type":"function","title":"MutableMap.import_list/2","doc":"","ref":"MutableMap.html#import_list/2"},{"type":"function","title":"MutableMap.keys/1","doc":"","ref":"MutableMap.html#keys/1"},{"type":"function","title":"MutableMap.new/0","doc":"","ref":"MutableMap.html#new/0"},{"type":"function","title":"MutableMap.new/1","doc":"","ref":"MutableMap.html#new/1"},{"type":"function","title":"MutableMap.put/3","doc":"","ref":"MutableMap.html#put/3"},{"type":"function","title":"MutableMap.put_new/3","doc":"","ref":"MutableMap.html#put_new/3"},{"type":"function","title":"MutableMap.put_new_lazy/3","doc":"","ref":"MutableMap.html#put_new_lazy/3"},{"type":"function","title":"MutableMap.reduce/3","doc":"","ref":"MutableMap.html#reduce/3"},{"type":"function","title":"MutableMap.size/1","doc":"","ref":"MutableMap.html#size/1"},{"type":"function","title":"MutableMap.to_list/1","doc":"","ref":"MutableMap.html#to_list/1"},{"type":"function","title":"MutableMap.update/4","doc":"","ref":"MutableMap.html#update/4"},{"type":"type","title":"MutableMap.t/0","doc":"","ref":"MutableMap.html#t:t/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}